@@ -3,7 +3,7 @@ our $AUTHORITY = 'cpan:GENE';
 
 # ABSTRACT: Mock data creation
 
-our $VERSION = '0.1004';
+our $VERSION = '0.1100';
 
 use strict;
 use warnings;
@@ -273,7 +273,7 @@ sub distributor {
 
 sub shuffler {
     # Get the desired number of data-points.
-    my $n = defined $_[0] ? shift : 9;
+    my $n = defined $_[0] ? shift : NDATA;
     # Get the items to shuffle.
     my @items = @_ ? @_ : ('a' .. 'j');
     return [ shuffle(@items) ];
@@ -361,9 +361,6 @@ sub collate {
     # Accept any number of columns.
     my @columns = @_;
 
-    # Make a copy of the columns to peel off.
-    my @lists = @columns;
-
     # Declare the bucket for our arrayrefs.
     my @results = ();
 
@@ -391,7 +388,7 @@ Mock::Populate - Mock data creation
 
 =head1 VERSION
 
-version 0.1004
+version 0.1100
 
 =head1 SYNOPSIS
 
@@ -545,13 +542,13 @@ This function uses single letter identifiers:
 
 =head2 shuffler()
 
-  $results = shuffler($n, @items)
+  $results = shuffler($N, @items)
 
-Return a shuffled list of B<$n> items.  The B<items> and number of data-points
+Return a shuffled list of B<N> B<items>.  The items and number of data-points
 are optional.  The defaults are:
 
   items: a b c d e f g h i j
-  n:     10
+  N:     10
 
 =head2 string_ranger()
 
